@@ -87,6 +87,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         self.default_navigation_timeout: Optional[float] = None
         if "PLAYWRIGHT_DEFAULT_NAVIGATION_TIMEOUT" in crawler.settings:
             with suppress(TypeError, ValueError):
+                logger.info("Set default navigation timeout")
                 self.default_navigation_timeout = float(
                     crawler.settings.get("PLAYWRIGHT_DEFAULT_NAVIGATION_TIMEOUT")
                 )
@@ -251,18 +252,21 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             result = await self._download_request_with_page(request, page)
         except:
             logger.exception(f"[{request.url}] Error while downloading request")
-            return Response('', status=504)
+            #return Response('', status=504)
         else:
             return result
         finally:
+            logger.info(f"[{request.url}] Start finally")
             try:
                 if page is not None:
                     if not page.is_closed():
+                        logger.info(f"[{request.url}] Close page")
                         await page.close()
             except:
                 logger.error(f"[{request.url}] Error on page close")
                 raise
             if self.context_semaphores['default'].locked():
+                logger.info(f"[{request.url}] Release semaphore")
                 self.context_semaphores['default'].release()
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
